@@ -356,7 +356,7 @@ class DeleteIfAppropriateTest(unittest.TestCase):
         mock_cert_path_for_cert_name.return_value = "/some/reasonable/path"
         mock_overlapping_archive_dirs.return_value = False
         self._call(config)
-        mock_delete.assert_called_once()
+        self.assertEqual(mock_delete.call_count, 1)
 
     # pylint: disable=too-many-arguments
     @mock.patch('certbot.storage.renewal_file_for_certname')
@@ -375,7 +375,7 @@ class DeleteIfAppropriateTest(unittest.TestCase):
         mock_cert_path_to_lineage.return_value = "example.com"
         mock_overlapping_archive_dirs.return_value = False
         self._call(config)
-        mock_delete.assert_called_once()
+        self.assertEqual(mock_delete.call_count, 1)
 
     # pylint: disable=too-many-arguments
     @mock.patch('certbot.storage.renewal_file_for_certname')
@@ -396,7 +396,7 @@ class DeleteIfAppropriateTest(unittest.TestCase):
         mock_full_archive_dir.return_value = ""
         mock_match_and_check_overlaps.return_value = ""
         self._call(config)
-        mock_delete.assert_called_once()
+        self.assertEqual(mock_delete.call_count, 1)
 
     # pylint: disable=too-many-arguments
     @mock.patch('certbot.storage.renewal_file_for_certname')
@@ -415,7 +415,7 @@ class DeleteIfAppropriateTest(unittest.TestCase):
         mock_cert_path_to_lineage.return_value = config.certname
         mock_overlapping_archive_dirs.return_value = False
         self._call(config)
-        mock_delete.assert_called_once()
+        self.assertEqual(mock_delete.call_count, 1)
 
     # pylint: disable=too-many-arguments
     @mock.patch('certbot.cert_manager.match_and_check_overlaps')
@@ -442,7 +442,7 @@ class DeleteIfAppropriateTest(unittest.TestCase):
         util_mock = mock_get_utility()
         util_mock.menu.return_value = (display_util.OK, 0)
         self._call(config)
-        mock_delete.assert_called_once()
+        self.assertEqual(mock_delete.call_count, 1)
 
     # pylint: disable=too-many-arguments
     @mock.patch('certbot.cert_manager.match_and_check_overlaps')
